@@ -202,10 +202,6 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 	else {
 		g_assert_not_reached();
 	}
-
-	load_graph_reset_colors(procdata->cpu_graph);
-	load_graph_reset_colors(procdata->mem_graph);
-	load_graph_reset_colors(procdata->net_graph);
 }
 
 
@@ -475,7 +471,7 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefi
 		}
 	}
 
-	if(g_str_has_suffix(prefix, "proctree"))
+	if(g_str_has_suffix(prefix, "proctree") || g_str_has_suffix(prefix, "disktreenew"))
 	{
 		GSList *order;
 		char *key;
@@ -542,7 +538,7 @@ procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *pref
 		g_free (key);
 	}
 
-	if(g_str_has_suffix(prefix, "proctree"))
+	if(g_str_has_suffix(prefix, "proctree") || g_str_has_suffix(prefix, "disktreenew"))
 	{
 		GSList *order;
 		char *key;
